@@ -33,7 +33,9 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 
 GST_DEBUG_CATEGORY_STATIC (gst_filesink_debug);
@@ -66,6 +68,7 @@ gst_filesink_get_formats (GstPad * pad)
     GST_FORMAT_BYTES,
     0,
   };
+
   return formats;
 }
 
@@ -77,6 +80,7 @@ gst_filesink_get_query_types (GstPad * pad)
     GST_QUERY_POSITION,
     0
   };
+
   return types;
 }
 
@@ -110,6 +114,7 @@ _do_init (GType filesink_type)
     NULL,
     NULL
   };
+
   g_type_add_interface_static (filesink_type, GST_TYPE_URI_HANDLER,
       &urihandler_info);
   GST_DEBUG_CATEGORY_INIT (gst_filesink_debug, "filesink", 0,
@@ -329,21 +334,30 @@ gst_filesink_handle_event (GstPad * pad, GstEvent * event)
 
   filesink = GST_FILESINK (gst_pad_get_parent (pad));
 
-  /* FIXME: should the event be unreferenced ? */
-  if (! (GST_FLAG_IS_SET (filesink, GST_FILESINK_OPEN))) return FALSE;
+
+  if (!(GST_FLAG_IS_SET (filesink, GST_FILESINK_OPEN))) {
+    gst_event_unref (event);
+    return FALSE;
+  }
+
 
   type = event ? GST_EVENT_TYPE (event) : GST_EVENT_UNKNOWN;
 
   switch (type) {
     case GST_EVENT_SEEK:
-      g_return_val_if_fail (GST_EVENT_SEEK_FORMAT (event) == GST_FORMAT_BYTES,
-          FALSE);
+      if (GST_EVENT_SEEK_FORMAT (event) != GST_FORMAT_BYTES) {
+        gst_event_unref (event);
+        return FALSE;
+      }
 
-      if (GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH)
-        if (fflush (filesink->file))
+      if (GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH) {
+        if (fflush (filesink->file)) {
+          gst_event_unref (event);
           GST_ELEMENT_ERROR (filesink, RESOURCE, WRITE,
               (_("Error while writing to file \"%s\"."), filesink->filename),
               GST_ERROR_SYSTEM);
+        }
+      }
 
       switch (GST_EVENT_SEEK_METHOD (event)) {
         case GST_SEEK_METHOD_SET:
@@ -359,6 +373,7 @@ gst_filesink_handle_event (GstPad * pad, GstEvent * event)
           g_warning ("unknown seek method!");
           break;
       }
+      gst_event_unref (event);
       break;
     case GST_EVENT_DISCONTINUOUS:
     {
@@ -372,12 +387,14 @@ gst_filesink_handle_event (GstPad * pad, GstEvent * event)
     }
     case GST_EVENT_FLUSH:
       if (fflush (filesink->file)) {
+        gst_event_unref (event);
         GST_ELEMENT_ERROR (filesink, RESOURCE, WRITE,
             (_("Error while writing to file \"%s\"."), filesink->filename),
             GST_ERROR_SYSTEM);
       }
       break;
     case GST_EVENT_EOS:
+      gst_event_unref (event);
       gst_filesink_close_file (filesink);
       gst_element_set_eos (GST_ELEMENT (filesink));
       break;
@@ -478,6 +495,7 @@ static gchar **
 gst_filesink_uri_get_protocols (void)
 {
   static gchar *protocols[] = { "file", NULL };
+
   return protocols;
 }
 static const gchar *
