@@ -58,6 +58,7 @@ gst_element_factory_get_type (void)
       (GInstanceInitFunc) gst_element_factory_init,
       NULL
     };
+
     elementfactory_type = g_type_register_static (GST_TYPE_PLUGIN_FEATURE,
         "GstElementFactory", &elementfactory_info, 0);
     GST_DEBUG_CATEGORY_INIT (element_factory_debug, "GST_ELEMENT_FACTORY",
@@ -158,7 +159,7 @@ gst_element_factory_cleanup (GstElementFactory * factory)
     factory->type = 0;
   }
 
-  g_list_foreach (factory->padtemplates, (GFunc) g_object_unref, NULL);
+  g_list_foreach (factory->padtemplates, (GFunc) gst_object_unref, NULL);
   g_list_free (factory->padtemplates);
   factory->padtemplates = NULL;
   factory->numpadtemplates = 0;
@@ -175,12 +176,12 @@ gst_element_factory_cleanup (GstElementFactory * factory)
 
 /**
  * gst_element_register:
- * @plugin:
+ * @plugin: #GstPlugin to register the element with
  * @name: name of elements of this type
  * @rank: rank of element (higher rank means more importance when autoplugging)
  * @type: GType of element to register
  *
- * Create a new elementfactory capable of insantiating objects of the
+ * Create a new elementfactory capable of instantiating objects of the
  * given type.
  *
  * Returns: TRUE, if the registering succeeded, FALSE on error
@@ -217,7 +218,7 @@ gst_element_register (GstPlugin * plugin, const gchar * name, guint rank,
   factory->type = type;
   __gst_element_details_copy (&factory->details, &klass->details);
   factory->padtemplates = g_list_copy (klass->padtemplates);
-  g_list_foreach (factory->padtemplates, (GFunc) g_object_ref, NULL);
+  g_list_foreach (factory->padtemplates, (GFunc) gst_object_ref, NULL);
   factory->numpadtemplates = klass->numpadtemplates;
 
   /* special stuff for URI handling */
