@@ -511,13 +511,20 @@ GstPadTemplate*		gst_pad_template_new			(const gchar *name_template,
 
 GstPadTemplate *	gst_static_pad_template_get             (GstStaticPadTemplate *pad_template);
 const GstCaps*		gst_pad_template_get_caps		(GstPadTemplate *templ);
+#ifndef GST_DISABLE_DEPRECATED
 const GstCaps*		gst_pad_template_get_caps_by_name	(GstPadTemplate *templ, const gchar *name);
+#endif
 
 #ifndef GST_DISABLE_LOADSAVE
 xmlNodePtr              gst_ghost_pad_save_thyself   		(GstPad *pad,
 						     		 xmlNodePtr parent);
 #endif
 
+/* for schedulers only */
+void			gst_pad_call_chain_function		(GstPad *pad, GstData *data);
+GstData *		gst_pad_call_get_function		(GstPad *pad);
+
+
 G_END_DECLS
 
 
