@@ -39,12 +39,14 @@ G_BEGIN_DECLS
 #define GST_VALUE_HOLDS_INT_RANGE(x)    (G_VALUE_HOLDS(x, gst_type_int_range))
 #define GST_VALUE_HOLDS_DOUBLE_RANGE(x) (G_VALUE_HOLDS(x, gst_type_double_range))
 #define GST_VALUE_HOLDS_LIST(x)         (G_VALUE_HOLDS(x, gst_type_list))
+#define GST_VALUE_HOLDS_FIXED_LIST(x)   (G_VALUE_HOLDS(x, gst_type_fixed_list))
 #define GST_VALUE_HOLDS_CAPS(x)		(G_VALUE_HOLDS(x, GST_TYPE_CAPS))
 
 #define GST_TYPE_FOURCC                  gst_type_fourcc
 #define GST_TYPE_INT_RANGE               gst_type_int_range
 #define GST_TYPE_DOUBLE_RANGE            gst_type_double_range
 #define GST_TYPE_LIST                    gst_type_list
+#define GST_TYPE_FIXED_LIST              gst_type_fixed_list
 
 #define GST_VALUE_LESS_THAN              (-1)
 #define GST_VALUE_EQUAL                   0
@@ -62,6 +64,9 @@ typedef int      (* GstValueUnionFunc)       (GValue       *dest,
 typedef int      (* GstValueIntersectFunc)   (GValue       *dest,
 					      const GValue *value1,
 					      const GValue *value2);
+typedef int      (* GstValueSubtractFunc)    (GValue       *dest,
+					      const GValue *minuend,
+					      const GValue *subtrahend);
 
 typedef struct _GstValueTable GstValueTable;
 struct _GstValueTable {
@@ -77,6 +82,7 @@ extern GType gst_type_fourcc;
 extern GType gst_type_int_range;
 extern GType gst_type_double_range;
 extern GType gst_type_list;
+extern GType gst_type_fixed_list;
 
 void                     gst_value_register                (const GstValueTable   *table);
 void                     gst_value_init_and_copy           (GValue                *dest,
@@ -148,6 +154,19 @@ void                     gst_value_register_intersect_func (GType
 							    GType                 type2,
 							    GstValueIntersectFunc func);
 
+/* subtraction */
+gboolean		 gst_value_subtract		   (GValue		  *dest,
+							    const GValue      	  *minuend,
+							    const GValue      	  *subtrahend);
+gboolean		 gst_value_can_subtract		   (const GValue      	  *minuend,
+							    const GValue      	  *subtrahend);
+void                     gst_value_register_subtract_func  (GType                 minuend_type,
+							    GType                 subtrahend_type,
+							    GstValueSubtractFunc  func);
+
+/* fixation */
+gboolean                 gst_type_is_fixed                 (GType type);
+
 /* private */
 void                     _gst_value_initialize (void);
 
