@@ -13,7 +13,8 @@ create_pipeline (void)
   bin = gst_bin_new ("bin");
   fakesink = gst_element_factory_make ("fakesink", "fakesink");
   gst_bin_add (GST_BIN (bin), fakesink);
-  gst_element_add_ghost_pad (bin, gst_element_get_pad (fakesink, "sink"), "sink");
+  gst_element_add_ghost_pad (bin, gst_element_get_pad (fakesink, "sink"),
+      "sink");
 
   gst_element_link (fakesrc, bin);
 
@@ -25,13 +26,13 @@ create_pipeline (void)
 }
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc, gchar * argv[])
 {
   GstElement *pipeline;
   gint i = 1000;
   gint step = 100;
 
-  free (malloc(8)); /* -lefence */
+  free (malloc (8));            /* -lefence */
 
   gst_init (&argc, &argv);
 
@@ -41,7 +42,7 @@ main (gint argc, gchar *argv[])
     if (i % step == 0)
       fprintf (stderr, "%10d\r", i);
     pipeline = create_pipeline ();
-	  
+
     gst_element_set_state (pipeline, GST_STATE_PLAYING);
 
     while (gst_bin_iterate (GST_BIN (pipeline)));
